@@ -1,5 +1,5 @@
-#ifndef _XML_H_
-#define _XML_H_
+#ifndef XML_H
+#define XML_H
 
 #include <stdio.h>
 
